@@ -185,8 +185,6 @@ def check(args, parser):
             print ('Directory {0} does not exist, run checkout.'
                    .format(branch_dir))
 
-def bash(args, parser):
-
 
 def bind(args, parser):
     if args.interfaces:
@@ -255,23 +253,6 @@ def bind(args, parser):
 
 # Helper functions:
 
-def get_project():
-
-    def walk(cur):
-        if 'Dockerfile' in os.listdir(cur):
-            return os.path.basename(cur)
-        new = os.path.dirname(cur)
-        if new == cur:
-            raise ValueError('Dockerfile not find in current parent directories.')
-        return walk(new)
-
-    project = walk(os.getcwd())
-    if project not in BRANCHES:
-        raise ValueError('Project {0} not a valid branch.'.format(project))
-
-    return project
-
-
 def get_config_value(section, key, default=None):
     config = configparser.ConfigParser()
     config.read(CONFIG_PATH)
@@ -424,11 +405,6 @@ def create_parser():
     )
     parser_check.set_defaults(func=check)
 
-    parser_bash = subparsers.add_parser(
-        'bash', help='Bash prompt for a container for this image'
-    )
-    parser_check.set_defaults(func=check)
-
     parser_up = subparsers.add_parser(
         'up', help='Recreates fig.yml and starts the '
                    'containers in the background, a wrapper around `fig up`'
@@ -443,7 +419,6 @@ def create_parser():
         metavar="IMAGE_NAME",
     )
     parser_shell.set_defaults(func=shell)
-
     parser_shell = subparsers.add_parser(
         'chkgitconfig', help='Print out the git config for mkt branches'
     )
